@@ -48,7 +48,8 @@ gint workaround_offset = 1;
 
 
 static
-gboolean timeout (gpointer data) {
+gboolean timeout (gpointer data)
+{
     GtkWidget *widget = GTK_WIDGET (data);
     gtk_widget_queue_draw (widget);
     return TRUE;
@@ -60,7 +61,6 @@ static GdkPixbuf *
 get_rectangle_screenshot (gint x, gint y) {
     GdkPixbuf *screenshot = NULL;
     GdkWindow *root_window = gdk_get_default_root_window ();
-    GdkColormap *colormap = gdk_colormap_get_system();
     gint width = CIRCLE_SIZE + workaround_offset;
     gint height = CIRCLE_SIZE + workaround_offset;
 
@@ -74,10 +74,9 @@ get_rectangle_screenshot (gint x, gint y) {
         y = 0;
     }
 
-    screenshot = gdk_pixbuf_get_from_drawable (NULL, root_window, colormap,
-                                               x, y,
-                                               0, 0,
-                                               width, height);
+    screenshot = gdk_pixbuf_get_from_window (root_window,
+                                             x, y,
+                                             width, height);
     return screenshot;
 }
 
@@ -95,19 +94,19 @@ find_cursor_motion_notify_event (GtkWidget      *widget,
 
 static gboolean
 find_cursor_window_composited (GtkWidget *widget) {
-    gboolean     composited;
     GdkScreen   *screen = gtk_widget_get_screen (widget);
-    GdkColormap *colormap = gdk_screen_get_rgba_colormap (screen);
+    GdkVisual   *visual = gdk_screen_get_rgba_visual (screen);
+    gboolean     composited;
 
     if (gdk_screen_is_composited (screen))
-       composited = TRUE;
+        composited = TRUE;
     else
     {
-       colormap = gdk_screen_get_rgb_colormap (screen);
-       composited = FALSE;
+        visual = gdk_screen_get_system_visual (screen);
+        composited = FALSE;
     }
 
-    gtk_widget_set_colormap (widget, colormap);
+    gtk_widget_set_visual (widget, visual);
     return composited;
 }
 
@@ -124,16 +123,13 @@ find_cursor_window_destroy (GtkWidget *widget,
 
 
 static gboolean
-find_cursor_window_expose (GtkWidget       *widget,
-                           GdkEventExpose  *event,
-                           gpointer         user_data) {
-    cairo_t *cr;
-    int      i = 0;
-    int      arcs = 1;
+find_cursor_window_draw (GtkWidget      *widget,
+                         cairo_t        *cr,
+                         gpointer        user_data) {
+    int i = 0;
+    int arcs = 1;
     gboolean composited = GPOINTER_TO_INT (user_data);
 
-    cr = gdk_cairo_create (event->window);
-
     if (composited) {
         cairo_set_operator (cr, CAIRO_OPERATOR_SOURCE);
         cairo_set_source_rgba (cr, 1.0, 1.0, 1.0, 0.0);
@@ -150,7 +146,6 @@ find_cursor_window_expose (GtkWidget       *widget,
         else
             g_warning ("Something with the screenshot went wrong.");
     }
-
     cairo_paint (cr);
 
     cairo_set_line_width (cr, 3.0);
@@ -182,19 +177,21 @@ find_cursor_window_expose (GtkWidget       *widget,
 
     px += 3;
 
-    cairo_destroy (cr);
-
     return FALSE;
 }
 
 
 
 gint
-main (gint argc, gchar **argv) {
+main (gint argc, gchar **argv)
+{
     XfconfChannel *accessibility_channel = NULL;
     GError        *error = NULL;
     GtkWidget     *window;
-    GdkWindow     *root_window;
+    GdkDisplay    *display;
+    GdkSeat       *seat;
+    GdkDevice     *device;
+    GdkScreen     *screen;
     gint           x,y;
     gboolean       composited;
 
@@ -217,8 +214,11 @@ main (gint argc, gchar **argv) {
     gtk_init (&argc, &argv);
 
     /* just get the position of the mouse cursor */
-    root_window = gdk_get_default_root_window ();
-    gdk_window_get_pointer (root_window, &x, &y, NULL);
+    display = gdk_display_get_default ();
+    seat = gdk_display_get_default_seat (display);
+    device = gdk_seat_get_pointer (seat);
+    screen = gdk_screen_get_default ();
+    gdk_device_get_position (device, &screen, &x, &y);
 
     /* popup tells the wm to ignore if parts of the window are offscreen */
     window = gtk_window_new (GTK_WINDOW_POPUP);
@@ -252,8 +252,9 @@ main (gint argc, gchar **argv) {
         if (!pixbuf)
             g_warning ("Getting screenshot failed");
     }
-    g_signal_connect (G_OBJECT (window), "expose-event",
-                      G_CALLBACK (find_cursor_window_expose), GINT_TO_POINTER (composited));
+
+    g_signal_connect (G_OBJECT (window), "draw",
+                      G_CALLBACK (find_cursor_window_draw), GINT_TO_POINTER (composited));
     g_signal_connect (G_OBJECT (window), "destroy",
                       G_CALLBACK (find_cursor_window_destroy), NULL);
 
