@@ -609,7 +609,7 @@ appearance_settings_load_icon_themes (preview_data *pd)
     /* Free the check list */
     if (G_LIKELY (check_list))
     {
-        g_slist_foreach (check_list, (GFunc) g_free, NULL);
+        g_slist_foreach (check_list, (GFunc) (void (*)(void)) g_free, NULL);
         g_slist_free (check_list);
     }
 
@@ -757,7 +757,7 @@ appearance_settings_load_ui_themes (preview_data *pd)
     /* Free the check list */
     if (G_LIKELY (check_list))
     {
-        g_slist_foreach (check_list, (GFunc) g_free, NULL);
+        g_slist_foreach (check_list, (GFunc) (void (*)(void)) g_free, NULL);
         g_slist_free (check_list);
     }
 
@@ -1320,7 +1320,7 @@ main (gint argc, gchar **argv)
     if (G_UNLIKELY (opt_version))
     {
         g_print ("%s %s (Xfce %s)\n\n", G_LOG_DOMAIN, PACKAGE_VERSION, xfce_version_string ());
-        g_print ("%s\n", "Copyright (c) 2008-2011");
+        g_print ("%s\n", "Copyright (c) 2008-2018");
         g_print ("\t%s\n\n", _("The Xfce development team. All rights reserved."));
         g_print (_("Please report bugs to <%s>."), PACKAGE_BUGREPORT);
         g_print ("\n");
