@@ -1198,11 +1198,11 @@ xfce_keyboard_settings_edit_button_clicked (XfceKeyboardSettings *settings)
     }
 
   /* Free row reference list */
-  g_list_foreach (row_references, (GFunc) gtk_tree_row_reference_free, NULL);
+  g_list_foreach (row_references, (GFunc) (void (*)(void)) gtk_tree_row_reference_free, NULL);
   g_list_free (row_references);
 
   /* Free row list */
-  g_list_foreach (rows, (GFunc) gtk_tree_path_free, NULL);
+  g_list_foreach (rows, (GFunc) (void (*)(void)) gtk_tree_path_free, NULL);
   g_list_free (rows);
 }
 
@@ -1255,11 +1255,11 @@ xfce_keyboard_settings_delete_button_clicked (XfceKeyboardSettings *settings)
     }
 
   /* Free row reference list */
-  g_list_foreach (row_references, (GFunc) gtk_tree_row_reference_free, NULL);
+  g_list_foreach (row_references, (GFunc) (void (*)(void)) gtk_tree_row_reference_free, NULL);
   g_list_free (row_references);
 
   /* Free row list */
-  g_list_foreach (rows, (GFunc) gtk_tree_path_free, NULL);
+  g_list_foreach (rows, (GFunc) (void (*)(void)) gtk_tree_path_free, NULL);
   g_list_free (rows);
 }
 
